@@ -16,6 +16,7 @@ sub new {
         widgets => [],
         tags    => [],
         meta    => {},
+        enclosures => [],
     }, $class;
 }
 
@@ -68,5 +69,29 @@ sub body_text {
     Plagger::Util::strip_html($self->body);
 }
 
+sub add_enclosure {
+    my($self, $enclosure) = @_;
+
+    # don't add enclosure with the same URL again and again
+    unless ($enclosure->url && grep { $_->url && $_->url eq $enclosure->url } $self->enclosures) {
+        push @{ $self->{enclosures} }, $enclosure;
+    }
+}
+
+sub enclosure {
+    my $self = shift;
+    wantarray ? @{$self->{enclosures}} : $self->{enclosures}->[0];
+}
+
+sub enclosures {
+    my $self = shift;
+    wantarray ? @{$self->{enclosures}} : $self->{enclosures};
+}
+
+sub has_enclosure {
+    my $self = shift;
+    scalar @{$self->{enclosures}} > 0;
+}
+
 1;
 
