@@ -57,13 +57,26 @@ sub publish_feed {
         $entry->category(join(' ', @{$e->tags}));
         $entry->issued($e->date) if $e->date;
         $entry->author($e->author);
+
+        if ($e->has_enclosure) {
+            # RSS 2.0 by spec doesn't allow multiple enclosures
+            my @enclosures = $feed_format eq 'RSS' ? ($e->enclosures->[0]) : $e->enclosures;
+            for my $enclosure (grep { defined $_->url && !$_->is_inline } @enclosures) {
+                $entry->add_enclosure({
+                    url    => $enclosure->url,
+                    length => $enclosure->length,
+                    type   => $enclosure->type,
+                });
+            }
+        }
+
         $feed->add_entry($entry);
     }
 
     # generate file path
     my $filepath = File::Spec->catfile($self->conf->{dir}, $self->gen_filename($f));
 
-    $context->log(info => "save feed for " . $f->url . " to $filepath");
+    $context->log(info => "save feed for " . $f->link . " to $filepath");
 
     my $xml = $feed->as_xml;
     utf8::decode($xml) unless utf8::is_utf8($xml);
@@ -99,6 +112,27 @@ sub safe_filename {
     $path;
 }
 
+# XXX okay, this is a hack until XML::Feed is updated
+*XML::Feed::Entry::Atom::add_enclosure = sub {
+    my($entry, $enclosure) = @_;
+    my $link = XML::Atom::Link->new;
+    $link->rel('enclosure');
+    $link->type($enclosure->{type});
+    $link->href($enclosure->{url});
+    $link->length($enclosure->{length});
+    $entry->{entry}->add_link($link);
+};
+
+*XML::Feed::Entry::RSS::add_enclosure = sub {
+    my($entry, $enclosure) = @_;
+    $entry->{entry}->{enclosure} = {
+        url    => $enclosure->{url},
+        type   => $enclosure->{type},
+        length => $enclosure->{length},
+    };
+};
+
+
 1;
 
 __END__
@@ -156,6 +190,10 @@ like printf():
 
 Yoshiki KURIHARA
 
+Tatsuhiko Miyagawa
+
+Gosuke Miyashita
+
 =head1 SEE ALSO
 
 L<Plagger>, L<XML::Feed>
